Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src\derivepassphrase\__init__.py | 3 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\_internals\__init__.py | 5 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\_internals\cli_helpers.py | 314 | 8 | 27 | 58 | 2 | 97.312%
src\derivepassphrase\_internals\cli_machinery.py | 339 | 0 | 46 | 80 | 0 | 100.000%
src\derivepassphrase\_internals\cli_messages.py | 477 | 0 | 392 | 30 | 0 | 100.000%
src\derivepassphrase\_types.py | 273 | 0 | 61 | 68 | 0 | 100.000%
src\derivepassphrase\cli.py | 466 | 0 | 9 | 156 | 0 | 100.000%
src\derivepassphrase\exporter\__init__.py | 46 | 0 | 82 | 12 | 0 | 100.000%
src\derivepassphrase\exporter\storeroom.py | 207 | 0 | 24 | 38 | 0 | 100.000%
src\derivepassphrase\exporter\vault_native.py | 204 | 0 | 36 | 14 | 0 | 100.000%
src\derivepassphrase\sequin.py | 109 | 0 | 2 | 44 | 0 | 100.000%
src\derivepassphrase\ssh_agent\__init__.py | 185 | 4 | 54 | 42 | 1 | 97.797%
src\derivepassphrase\ssh_agent\socketprovider.py | 85 | 9 | 8 | 28 | 2 | 88.496%
src\derivepassphrase\vault.py | 154 | 2 | 3 | 40 | 1 | 98.454%
tests\__init__.py | 531 | 4 | 101 | 92 | 3 | 98.876%
tests\conftest.py | 58 | 4 | 444 | 2 | 0 | 93.333%
tests\test_derivepassphrase_cli.py | 1851 | 21 | 90 | 132 | 0 | 98.941%
tests\test_derivepassphrase_cli_export_vault.py | 220 | 0 | 7 | 2 | 0 | 100.000%
tests\test_derivepassphrase_exporter.py | 134 | 0 | 18 | 12 | 0 | 100.000%
tests\test_derivepassphrase_sequin.py | 196 | 1 | 10 | 32 | 1 | 99.123%
tests\test_derivepassphrase_ssh_agent.py | 420 | 11 | 23 | 34 | 0 | 97.137%
tests\test_derivepassphrase_types.py | 60 | 0 | 4 | 4 | 0 | 100.000%
tests\test_derivepassphrase_vault.py | 194 | 0 | 9 | 24 | 0 | 100.000%
tests\test_l10n.py | 127 | 0 | 8 | 4 | 0 | 100.000%
Total | 6658 | 64 | 1458 | 948 | 10 | 98.974%

No items found using the specified filter.